<?php
/**
 * Offers Section options
 *
 * @offer Theme Palace
 * @suboffer Pleased Pro
 * @since Pleased Pro 1.0.0
 */

// Add Offers section
$wp_customize->add_section( 'pleased_pro_offer_section', array(
	'title'             => esc_html__( 'Special Offers','pleased-pro' ),
	'description'       => esc_html__( 'Offers Section options.', 'pleased-pro' ),
	'panel'             => 'pleased_pro_front_page_panel',
) );

// Offers content enable control and setting
$wp_customize->add_setting( 'pleased_pro_theme_options[offer_section_enable]', array(
	'default'			=> 	$options['offer_section_enable'],
	'sanitize_callback' => 'pleased_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Pleased_Pro_Switch_Control( $wp_customize, 'pleased_pro_theme_options[offer_section_enable]', array(
	'label'             => esc_html__( 'Offers Section Enable', 'pleased-pro' ),
	'section'           => 'pleased_pro_offer_section',
	'on_off_label' 		=> pleased_pro_switch_options(),
) ) );

// offer title setting and control
$wp_customize->add_setting( 'pleased_pro_theme_options[offer_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['offer_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'pleased_pro_theme_options[offer_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'pleased-pro' ),
	'section'        	=> 'pleased_pro_offer_section',
	'active_callback' 	=> 'pleased_pro_is_offer_section_enable',
	'type'				=> 'text',
) );

// offer title setting and control
$wp_customize->add_setting( 'pleased_pro_theme_options[offer_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['offer_btn_label'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'pleased_pro_theme_options[offer_btn_label]', array(
	'label'           	=> esc_html__( 'Button Label', 'pleased-pro' ),
	'section'        	=> 'pleased_pro_offer_section',
	'active_callback' 	=> 'pleased_pro_is_offer_section_enable',
	'type'				=> 'text',
) );

// banner image setting and control.
$wp_customize->add_setting( 'pleased_pro_theme_options[offer_background_image]', array(
	'sanitize_callback' => 'pleased_pro_sanitize_image',
	// 'default'          	=> $options['offer_background_image'],
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'pleased_pro_theme_options[offer_background_image]',
		array(
		'label'       		=> esc_html__( 'Background Image', 'pleased-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'pleased-pro' ), 1920, 1080 ),
		'section'     		=> 'pleased_pro_offer_section',
		'active_callback'	=> 'pleased_pro_is_offer_section_enable',
) ) );

// Offers social icons number control and setting
$wp_customize->add_setting( 'pleased_pro_theme_options[offer_count]', array(
	'default'          	=> $options['offer_count'],
	'sanitize_callback' => 'pleased_pro_sanitize_number_range',
	'validate_callback' => 'pleased_pro_validate_offer_count',
) );

$wp_customize->add_control( 'pleased_pro_theme_options[offer_count]', array(
	'label'             => esc_html__( 'Number of Offers', 'pleased-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'pleased-pro' ),
	'section'           => 'pleased_pro_offer_section',
	'active_callback'   => 'pleased_pro_is_offer_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
) );

// Offers content type control and setting
$wp_customize->add_setting( 'pleased_pro_theme_options[offer_content_type]', array(
	'default'          	=> $options['offer_content_type'],
	'sanitize_callback' => 'pleased_pro_sanitize_select',
) );

$wp_customize->add_control( 'pleased_pro_theme_options[offer_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'pleased-pro' ),
	'section'           => 'pleased_pro_offer_section',
	'type'				=> 'select',
	'active_callback' 	=> 'pleased_pro_is_offer_section_enable',
	'choices'			=> pleased_pro_offer_content_type(),
) );

for ( $i=1; $i <= $options['offer_count'] ; $i++ ) { 
	// offer pages drop down chooser control and setting
	$wp_customize->add_setting( 'pleased_pro_theme_options[offer_content_page_' . $i . ']', array(
		'sanitize_callback' => 'pleased_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Pleased_Pro_Dropdown_Chooser( $wp_customize, 'pleased_pro_theme_options[offer_content_page_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Page %d', 'pleased-pro' ), $i ),
		'section'           => 'pleased_pro_offer_section',
		'choices'			=> pleased_pro_page_choices(),
		'active_callback'	=> 'pleased_pro_is_offer_section_content_page_enable',
	) ) );

	// offer posts drop down chooser control and setting
	$wp_customize->add_setting( 'pleased_pro_theme_options[offer_content_post_' . $i . ']', array(
		'sanitize_callback' => 'pleased_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Pleased_Pro_Dropdown_Chooser( $wp_customize, 'pleased_pro_theme_options[offer_content_post_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select posts %d', 'pleased-pro' ), $i ),
		'section'           => 'pleased_pro_offer_section',
		'choices'			=> pleased_pro_post_choices(),
		'active_callback'	=> 'pleased_pro_is_offer_section_content_post_enable',
	) ) );

	// offer trips drop down chooser control and setting
	$wp_customize->add_setting( 'pleased_pro_theme_options[offer_content_trip_' . $i . ']', array(
		'sanitize_callback' => 'pleased_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Pleased_Pro_Dropdown_Chooser( $wp_customize, 'pleased_pro_theme_options[offer_content_trip_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Trip %d', 'pleased-pro' ), $i ),
		'section'           => 'pleased_pro_offer_section',
		'choices'			=> pleased_pro_trip_choices(),
		'active_callback'	=> 'pleased_pro_is_offer_section_content_trip_enable',
	) ) );
}

// Add dropdown category setting and control.
$wp_customize->add_setting(  'pleased_pro_theme_options[offer_content_category]', array(
	'sanitize_callback' => 'pleased_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Pleased_Pro_Dropdown_Taxonomies_Control( $wp_customize,'pleased_pro_theme_options[offer_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'pleased-pro' ),
	'section'           => 'pleased_pro_offer_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'pleased_pro_is_offer_section_content_category_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'pleased_pro_theme_options[offer_content_trip_types]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Pleased_Pro_Dropdown_Taxonomies_Control( $wp_customize,'pleased_pro_theme_options[offer_content_trip_types]', array(
	'label'             => esc_html__( 'Select Trip Types', 'pleased-pro' ),
	'section'           => 'pleased_pro_offer_section',
	'taxonomy'			=> 'itinerary_types',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'pleased_pro_is_offer_section_content_trip_types_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'pleased_pro_theme_options[offer_content_activity]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Pleased_Pro_Dropdown_Taxonomies_Control( $wp_customize,'pleased_pro_theme_options[offer_content_activity]', array(
	'label'             => esc_html__( 'Select Activities', 'pleased-pro' ),
	'section'           => 'pleased_pro_offer_section',
	'taxonomy'			=> 'activity',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'pleased_pro_is_offer_section_content_activity_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'pleased_pro_theme_options[offer_content_destination]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Pleased_Pro_Dropdown_Taxonomies_Control( $wp_customize,'pleased_pro_theme_options[offer_content_destination]', array(
	'label'             => esc_html__( 'Select Destinations', 'pleased-pro' ),
	'section'           => 'pleased_pro_offer_section',
	'taxonomy'			=> 'travel_locations',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'pleased_pro_is_offer_section_content_destination_enable'
) ) );
