<?php
/**
 * Contact section
 *
 * This is the template for the content of contact section
 *
 * @package Theme Palace
 * @subpackage Pleased Pro
 * @since Pleased Pro 1.0.0
 */
if ( ! function_exists( 'pleased_pro_add_contact_section' ) ) :
    /**
    * Add contact section
    *
    *@since Pleased Pro 1.0.0
    */
    function pleased_pro_add_contact_section() {
    	$options = pleased_pro_get_theme_options();
        // Check if contact is enabled on frontpage
        $contact_enable = apply_filters( 'pleased_pro_section_status', true, 'contact_section_enable' );

        if ( true !== $contact_enable ) {
            return false;
        }

        // Render contact section now.
        pleased_pro_render_contact_section();
    }
endif;

if ( ! function_exists( 'pleased_pro_render_contact_section' ) ) :
  /**
   * Start contact section
   *
   * @return string contact content
   * @since Pleased Pro 1.0.0
   *
   */
   function pleased_pro_render_contact_section() {
        $options = pleased_pro_get_theme_options();
        $contact_phone = ! empty( $options['contact_phone'] ) ? explode( '|', $options['contact_phone'] ) : array();
        $contact_email = ! empty( $options['contact_email'] ) ? explode( '|', $options['contact_email'] ) : array();
        $contact_social = ! empty( $options['contact_social'] ) ? explode( '|', $options['contact_social'] ) : array();
        ?>

        <div id="contact-us" class="clear <?php echo ! empty( $options['contact_map'] ) ? '' : 'map-off'; ?>">
            <?php if ( ! empty( $options['contact_map'] ) ) : ?>
                <?php echo do_shortcode( wp_kses_post( $options['contact_map'] ) ); ?>
            <?php endif; ?>

            <div class="contact-wrapper">
                    <?php if ( ! empty( $options['contact_title'] ) || ! empty( $options['contact_sub_title'] ) ) : ?>
                        <header class="entry-header">
                            <?php if ( ! empty( $options['contact_title'] ) ) : ?>
                                <h2 class="entry-title"><?php echo esc_html( $options['contact_title'] ); ?></h2>
                            <?php endif;

                            if ( ! empty( $options['contact_sub_title'] ) ) : ?>
                                <p><?php echo esc_html( $options['contact_sub_title'] ); ?></p>
                            <?php endif; ?>
                        </header>
                    <?php endif; ?>
                    

                <div class="entry-content">
                    <ul class="address-block">
                        <?php if ( ! empty( $options['contact_address'] ) ) : ?>
                            <li class="address"><label><?php esc_html_e( 'Address:', 'pleased-pro' ); ?></label>
                                <span><?php echo esc_html( $options['contact_address'] ); ?></span>
                            </li>
                        <?php endif; ?>

                        <?php if ( ! empty( $options['contact_phone'] ) ) : ?>
                            <li class="phone"><label><?php esc_html_e( 'Call Us:', 'pleased-pro' ); ?></label>
                                 <?php foreach ( $contact_phone as $phone ) : ?>
                                    <span><a href="tel:<?php echo esc_attr( $phone ); ?>"><?php echo esc_html( $phone ); ?></a></span>
                                <?php endforeach; ?>
                            </li>
                        <?php endif; ?>

                        <?php if ( ! empty( $options['contact_email'] ) ) : ?>
                            <li class="email"><label><?php esc_html_e( 'Email:', 'pleased-pro' ); ?></label>
                                <?php foreach ( $contact_email as $email ) : ?>
                                    <span><a href="mailto:<?php echo esc_attr( $email ); ?>"><?php echo esc_html( $email ); ?></a></span>
                                <?php endforeach; ?>
                            </li>
                        <?php endif; ?>
                       
                    </ul>
                </div>

                <?php if ( ! empty( $contact_social ) ) : ?>
                    <div class="social-icons">
                        <ul>
                            <?php foreach ( $contact_social as $social ) : ?>
                                <li>
                                    <a href="<?php echo esc_url( $social ); ?>">
                                        <?php echo pleased_pro_return_social_icon( $social ); ?>
                                    </a>
                                </li>
                            <?php endforeach; ?>
                        </ul>
                    </div><!-- .social-icons -->
                <?php endif; ?>
            </div><!-- .contact-wrapper -->
        </div><!-- #contact-us -->

    <?php }
endif;