<?php
/**
 * Offer section
 *
 * This is the template for the content of offer section
 *
 * @package Theme Palace
 * @subpackage Pleased Pro
 * @since Pleased Pro 1.0.0
 */
if ( ! function_exists( 'pleased_pro_add_offer_section' ) ) :
    /**
    * Add offer section
    *
    *@since Pleased Pro 1.0.0
    */
    function pleased_pro_add_offer_section() {
    	$options = pleased_pro_get_theme_options();
        // Check if offer is enabled on frontpage
        $offer_enable = apply_filters( 'pleased_pro_section_status', true, 'offer_section_enable' );

        if ( true !== $offer_enable ) {
            return false;
        }
        // Get offer section details
        $section_details = array();
        $section_details = apply_filters( 'pleased_pro_filter_offer_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render offer section now.
        pleased_pro_render_offer_section( $section_details );
    }
endif;

if ( ! function_exists( 'pleased_pro_get_offer_section_details' ) ) :
    /**
    * offer section details.
    *
    * @since Pleased Pro 1.0.0
    * @param array $input offer section details.
    */
    function pleased_pro_get_offer_section_details( $input ) {
        $options = pleased_pro_get_theme_options();

        // Content type.
        $offer_content_type  = $options['offer_content_type'];
        $offer_count    = ! empty( $options['offer_count'] ) ? $options['offer_count'] : 2;
        
        $content = array();
        switch ( $offer_content_type ) {
        	
            case 'category':
                $cat_id = ! empty( $options['offer_content_category'] ) ? $options['offer_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $offer_count ),
                    'cat'               => $cat_id,
                    'ignore_sticky_posts'   => true,
                    );    
            break;

            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= absint( $offer_count ); $i++ ) {
                    if ( ! empty( $options['offer_content_page_' . $i] ) )
                        $page_ids[] = $options['offer_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $offer_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= absint( $offer_count ); $i++ ) {
                    if ( ! empty( $options['offer_content_post_' . $i] ) )
                        $post_ids[] = $options['offer_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $offer_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'trip':

                if ( ! class_exists( 'WP_Travel' ) )
                    return;
                
                $page_ids = array();

                for ( $i = 1; $i <= absint( $offer_count ); $i++ ) {
                    if ( ! empty( $options['offer_content_trip_' . $i] ) )
                        $page_ids[] = $options['offer_content_trip_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'itineraries',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $offer_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'trip-types':

                if ( ! class_exists( 'WP_Travel' ) )
                    return;
                
                $cat_id = ! empty( $options['offer_content_trip_types'] ) ? $options['offer_content_trip_types'] : '';
                $args = array(
                    'post_type'      => 'itineraries',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'itinerary_types',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => absint( $offer_count ),
                    );                    
            break;

            case 'destination':

                if ( ! class_exists( 'WP_Travel' ) )
                    return;
                
                $cat_id = ! empty( $options['offer_content_destination'] ) ? $options['offer_content_destination'] : '';
                $args = array(
                    'post_type'      => 'itineraries',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'travel_locations',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => absint( $offer_count ),
                    );                    
            break;

            case 'activity':

                if ( ! class_exists( 'WP_Travel' ) )
                    return;
                
                $cat_id = ! empty( $options['offer_content_activity'] ) ? $options['offer_content_activity'] : '';
                $args = array(
                    'post_type'      => 'itineraries',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'activity',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => absint( $offer_count ),
                    );                    
            break;

            default:
            break;
        }

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = pleased_pro_trim_content( 35 );
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// offer section content details.
add_filter( 'pleased_pro_filter_offer_section_details', 'pleased_pro_get_offer_section_details' );


if ( ! function_exists( 'pleased_pro_render_offer_section' ) ) :
  /**
   * Start offer section
   *
   * @return string offer content
   * @since Pleased Pro 1.0.0
   *
   */
   function pleased_pro_render_offer_section( $content_details = array() ) {
        $options = pleased_pro_get_theme_options();
        $offer_content_type  = $options['offer_content_type'];
        $readmore = ! empty( $options['offer_btn_label'] ) ? $options['offer_btn_label'] : esc_html__( 'Book Now', 'pleased-pro' ); 
        $background = ! empty( $options['offer_background_image'] ) ? $options['offer_background_image'] : get_template_directory_uri() . '/assets/uploads/special.jpg'; 

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="special-menu" class="col-2 page-section" style="background-image: url('<?php echo esc_url( $background ); ?>');">
            <div class="wrapper">
                <div class="regular" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": true, "arrows":false, "autoplay": true, "fade": true }'>
                    <?php foreach  ( $content_details as $content ) : ?>
                        <article class="has-post-thumbnail">
                            <div class="special-wrapper">
                                <div class="entry-container clear">
                                    <div class="content-wrapper">
                                    <div class="section-header">
                                        <?php if ( ! empty( $options['offer_sub_title'] ) ) : ?>
                                            <span class="section-subtitle"><?php echo esc_html( $options['offer_sub_title'] ); ?></span>
                                        <?php endif; ?>
                                        <h2 class="section-title"><?php echo esc_html( $content['title'] ); ?></h2>
                                    </div><!-- .section-header -->
                                    <div class="section-content">
                                        <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                        <?php if ( ! in_array( $offer_content_type, array( 'page', 'post', 'category' ) ) ) : 
                                            $trip_price      = WP_Travel_Helpers_Pricings::get_price( array('trip_id'=>$content['id']) );
                                            $settings        = wp_travel_get_settings();
                                            ?>
                                            <span>
                                                <?php 
                                                    echo wp_travel_get_formated_price_currency( $trip_price );
                                                ?>
                                            </span>
                                        <?php endif; ?>
                                    </div><!-- .section-content -->
                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn btn-default"><?php echo esc_html( $readmore ); ?></a>
                                    </div>
                                </div><!-- .entry-container -->

                                <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">  
                                </div>
                            </div>
                        </article>
                    <?php endforeach; ?>
                </div>
            </div>
        </div>
        
    <?php }
endif;